@@ -394,10 +394,15 @@ ffmpeg_probe(Decoder *decoder, InputStream &is)
 	avpd.filename = is.uri.c_str();
 
 #ifdef AVPROBE_SCORE_MIME
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(56, 5, 1)
 	/* this attribute was added in libav/ffmpeg version 11, but
 	   unfortunately it's "uint8_t" instead of "char", and it's
 	   not "const" - wtf? */
 	avpd.mime_type = (uint8_t *)const_cast<char *>(is.GetMimeType());
+#else
+	/* API problem fixed in FFmpeg 2.5 */
+	avpd.mime_type = is.GetMimeType();
+#endif
 #endif
 
 	return av_probe_input_format(&avpd, true);
@@ -620,7 +625,7 @@ static const char *const ffmpeg_suffixes[] = {
 	"mj2", "mjpeg", "mjpg", "mka", "mkv", "mlp", "mm", "mmf", "mov", "mp+",
 	"mp1", "mp2", "mp3", "mp4", "mpc", "mpeg", "mpg", "mpga", "mpp", "mpu",
 	"mve", "mvi", "mxf", "nc", "nsv", "nut", "nuv", "oga", "ogm", "ogv",
-	"ogx", "oma", "ogg", "omg", "psp", "pva", "qcp", "qt", "r3d", "ra",
+	"ogx", "oma", "ogg", "omg", "opus", "psp", "pva", "qcp", "qt", "r3d", "ra",
 	"ram", "rl2", "rm", "rmvb", "roq", "rpl", "rvc", "shn", "smk", "snd",
 	"sol", "son", "spx", "str", "swf", "tgi", "tgq", "tgv", "thp", "ts",
 	"tsp", "tta", "xa", "xvid", "uv", "uv2", "vb", "vid", "vob", "voc",
@@ -654,6 +659,7 @@ static const char *const ffmpeg_mime_types[] = {
 	"audio/mpeg",
 	"audio/musepack",
 	"audio/ogg",
+	"audio/opus",
 	"audio/qcelp",
 	"audio/vorbis",
 	"audio/vorbis+ogg",
