@@ -802,6 +802,7 @@ alsa_play(struct audio_output *ao, const void *chunk, size_t size,
 {
 	AlsaOutput *ad = (AlsaOutput *)ao;
 
+	assert(size > 0);
 	assert(size % ad->in_frame_size == 0);
 
 	if (ad->must_prepare) {
@@ -814,11 +815,21 @@ alsa_play(struct audio_output *ao, const void *chunk, size_t size,
 		}
 	}
 
+	const size_t original_size = size;
 	chunk = ad->pcm_export->Export(chunk, size, size);
+	if (size == 0)
+		/* the DoP (DSD over PCM) filter converts two frames
+		   at a time and ignores the last odd frame; if there
+		   was only one frame (e.g. the last frame in the
+		   file), the result is empty; to avoid an endless
+		   loop, bail out here, and pretend the one frame has
+		   been played */
+		return original_size;
 
 	assert(size % ad->out_frame_size == 0);
 
 	size /= ad->out_frame_size;
+	assert(size > 0);
 
 	while (true) {
 		snd_pcm_sframes_t ret = ad->writei(ad->pcm, chunk, size);
